Documentation
¶
Index ¶
- type Parser
- type RuneTrie
- type UserAgent
- func (ua UserAgent) Browser() agents.Browser
- func (ua UserAgent) BrowserVersion() string
- func (ua UserAgent) BrowserVersionMajor() string
- func (ua UserAgent) BrowserVersionMinor() string
- func (ua UserAgent) BrowserVersionPatch() string
- func (ua UserAgent) Device() agents.Device
- func (ua UserAgent) GetBrowser() stringdeprecated
- func (ua UserAgent) GetDevice() stringdeprecated
- func (ua UserAgent) GetMajorVersion() stringdeprecated
- func (ua UserAgent) GetOS() stringdeprecated
- func (ua UserAgent) GetVersion() stringdeprecated
- func (ua UserAgent) IsBot() bool
- func (ua UserAgent) IsDesktop() bool
- func (ua UserAgent) IsMobile() bool
- func (ua UserAgent) IsTV() bool
- func (ua UserAgent) IsTablet() bool
- func (ua UserAgent) OS() agents.OS
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RuneTrie ¶
type RuneTrie struct {
// contains filtered or unexported fields
}
RuneTrie is a trie of runes with string keys and interface{} values.
type UserAgent ¶
type UserAgent struct {
// contains filtered or unexported fields
}
func (UserAgent) Browser ¶
Browser returns the browser name. If no browser is found, it returns an empty string.
func (UserAgent) BrowserVersion ¶
BrowserVersion returns the browser version. If no version is found, it returns an empty string.
func (UserAgent) BrowserVersionMajor ¶
BrowserVersionMajor returns the major version of the browser. If no version is found, it returns an empty string.
func (UserAgent) BrowserVersionMinor ¶
BrowserVersionMinor returns the minor version of the browser. If no version is found, it returns an empty string.
func (UserAgent) BrowserVersionPatch ¶
BrowserVersionPatch returns the patch version of the browser. If no version is found, it returns an empty string.
func (UserAgent) GetBrowser
deprecated
func (UserAgent) GetMajorVersion
deprecated
func (UserAgent) GetVersion
deprecated
Click to show internal directories.
Click to hide internal directories.